## Classification:

(Pick one of: Bug, Crash/Hang/Data Loss, Performance, UI/Usability, Feature (New), Enhancement)

## Reproducibility:

(Pick one of: Always, Sometimes, Rarely, Unable, I Didn't Try)

## Summary

Summary of the problem.

## Steps to Reproduce

- I do this
- I do that

## Expected Results

- This should happen.

## Actual Results

- Instead, this happens. :(

If helpful, submit screenshots of the issue to help debug. `autokey-gtk --verbose` output is also useful.

## Version

AutoKey-Py3 version ???

If the problem is known to be present in more than one version, please list all of those.

Installed via: (PPA, pip, …).

Distro:

## Notes

Describe any debugging steps you've taken yourself.

If you've found a workaround, provide it here.

